package
Version:
v0.0.0-...-156f350
Opens a new window with list of versions in this module.
Published: Jul 14, 2022
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package mouse handles all
mouse-oriented interactions.
FuncOverRange runs over a map
between the start and end
points against the supplied
function.
TileRange returns a
two-dimensional range
between start and end,
regardless of direction.
Mode enum for managing mouse action state.
const (
Normal Mode = iota
Storage
SleepHall
Farm
Brewery
Bar
Library
Delete
)
Mode enum.
type System struct {
Mode Mode
}
System for handling
all functionality by mouse.
func (*System) Handle ¶
Handle all the mouse interactivity.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.